@@ -19,6 +19,8 @@ import (
 	kcontroller "k8s.io/kubernetes/pkg/controller"
 
 	"github.com/openshift/library-go/pkg/apps/appsutil"
+
+	"github.com/openshift/openshift-controller-manager/pkg/metrics"
 )
 
 // NewDeployerController creates a new DeploymentController.
@@ -52,6 +54,8 @@ func NewDeployerController(
 		recorder:       recorder,
 	}
 
+	metrics.NewNamedWorkQueueMetrics("deployer")
+
 	rcInformer.Informer().AddEventHandler(cache.ResourceEventHandlerFuncs{
 		AddFunc:    c.addReplicationController,
 		UpdateFunc: c.updateReplicationController,
